src/cx/tree.h

changeset 1318
12fa1d37fe48
parent 1308
ce01b482daa3
child 1319
aa1f580f8f59
--- a/src/cx/tree.h	Thu May 15 15:43:30 2025 +0200
+++ b/src/cx/tree.h	Thu May 15 16:02:54 2025 +0200
@@ -213,7 +213,7 @@
  */
 cx_attr_nonnull
 static inline void cxTreeIteratorDispose(CxTreeIterator *iter) {
-    free(iter->stack);
+    cxFree(cxDefaultAllocator, iter->stack);
     iter->stack = NULL;
 }
 
@@ -226,7 +226,7 @@
     struct cx_tree_visitor_queue_s *q = visitor->queue_next;
     while (q != NULL) {
         struct cx_tree_visitor_queue_s *next = q->next;
-        free(q);
+        cxFree(cxDefaultAllocator, q);
         q = next;
     }
 }
@@ -443,7 +443,7 @@
  * Creates a depth-first iterator for a tree with the specified root node.
  *
  * @note A tree iterator needs to maintain a stack of visited nodes, which is
- * allocated using stdlib malloc().
+ * allocated using the cxDefaultAllocator.
  * When the iterator becomes invalid, this memory is automatically released.
  * However, if you wish to cancel the iteration before the iterator becomes
  * invalid by itself, you MUST call cxTreeIteratorDispose() manually to release
@@ -471,8 +471,8 @@
 /**
  * Creates a breadth-first iterator for a tree with the specified root node.
  *
  * @note A tree visitor needs to maintain a queue of to be visited nodes, which
  * is allocated using stdlib malloc().
  * When the visitor becomes invalid, this memory is automatically released.
  * However, if you wish to cancel the iteration before the visitor becomes
  * invalid by itself, you MUST call cxTreeVisitorDispose() manually to release
@@ -958,7 +958,7 @@
  * will free the nodes with the allocator's free() method.
  *
  * @param allocator the allocator that shall be used
  * (if @c NULL, a default stdlib allocator will be used)
  * @param create_func a function that creates new nodes
  * @param search_func a function that compares two nodes
  * @param search_data_func a function that compares a node with data
@@ -1022,7 +1022,7 @@
  * tree, you need to specify those functions afterwards.
  *
  * @param allocator the allocator that was used for nodes of the wrapped tree
  * (if @c NULL, a default stdlib allocator is assumed)
  * @param root the root node of the tree that shall be wrapped
  * @param loc_parent offset in the node struct for the parent pointer
  * @param loc_children offset in the node struct for the children linked list
@@ -471,8 +471,8 @@
  * Creates a breadth-first iterator for a tree with the specified root node.
  *
- * @note A tree visitor needs to maintain a queue of to be visited nodes, which
- * is allocated using stdlib malloc().
+ * @note A tree visitor needs to maintain a queue of to-be visited nodes, which
+ * is allocated using the cxDefaultAllocator.
  * When the visitor becomes invalid, this memory is automatically released.
  * However, if you wish to cancel the iteration before the visitor becomes
@@ -958,7 +958,7 @@
  *
  * @param allocator the allocator that shall be used
- * (if @c NULL, a default stdlib allocator will be used)
+ * (if @c NULL, the cxDefaultAllocator will be used)
  * @param create_func a function that creates new nodes
  * @param search_func a function that compares two nodes
@@ -1022,7 +1022,7 @@
  *
  * @param allocator the allocator that was used for nodes of the wrapped tree
- * (if @c NULL, a default stdlib allocator is assumed)
+ * (if @c NULL, the cxDefaultAllocator is assumed)
  * @param root the root node of the tree that shall be wrapped
  * @param loc_parent offset in the node struct for the parent pointer

mercurial